Coverage for /home/tribaal/workspace/django-shop/shop/urls/catalog: 100.00%

# Coverage for /home/tribaal/workspace/django-shop/shop/urls/catalog : 100.00%

## 5 statements 5 run 0 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 | from django.conf.urls.defaults import patterns, url from shop.views import ShopListView from shop.views.product import ProductDetailView from shop.models.productmodel import Product urlpatterns = patterns('', url(r'^$', ShopListView.as_view(model=Product), name='product_list' ), url(r'^(?P<slug>[0-9A-Za-z-_.//]+)/$', ProductDetailView.as_view(), name='product_detail' ), )